AnimatedGradientBorderGlow class
Fine-tuning configuration for AnimatedGradientBorder.glowEffect.
- Annotations
Constructors
- AnimatedGradientBorderGlow({double opacity = 0.55, double outerBlurSigma = 18, double innerBlurSigma = 8, double outerStrokeWidth = 14, double innerStrokeWidth = 8, double spread = 4, BlendMode blendMode = BlendMode.srcOver, Duration fadeDuration = const Duration(milliseconds: 220), Curve fadeCurve = Curves.easeOut})
-
const
Properties
- blendMode → BlendMode
-
Blend mode used by glow paint.
final
- fadeCurve → Curve
-
Curve used for glow fade transitions.
final
- fadeDuration → Duration
-
Duration of glow fade-in and fade-out when
glowEffectchanges.final - hashCode → int
-
The hash code for this object.
no setterinherited
- innerBlurSigma → double
-
Blur sigma of the sharper inner halo layer.
final
- innerStrokeWidth → double
-
Stroke width of the sharper inner halo layer.
final
- opacity → double
-
Overall glow strength multiplier.
final
- outerBlurSigma → double
-
Blur sigma of the soft outer halo layer.
final
- outerStrokeWidth → double
-
Stroke width of the soft outer halo layer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spread → double
-
Additional outside expansion for glow drawing.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited